"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const api = require("../../../api");
const config = require("../../../config");
const Tuner_1 = require("../../../Tuner");
let isScanning = false;
const compareOptions = {
    sensitivity: "base",
    numeric: true
};
const channelOrder = {
    GR: 1,
    BS: 2,
    CS: 3,
    SKY: 4
};
exports.put = async (req, res) => {
    if (isScanning === true) {
        api.responseError(res, 409, "Already Scanning");
        return;
    }
    isScanning = true;
    const type = req.query.type;
    const result = config.loadChannels().filter(channel => channel.type !== type);
    let count = 0;
    res.setHeader("Content-Type", "text/plain; charset=utf-8");
    res.status(200);
    res.write(`channel scanning... (type: "${type}")\n\n`);
    for (let i = req.query.min; i <= req.query.max; i++) {
        const channel = i.toString(10);
        res.write(`channel: "${channel}" ...\n`);
        let services;
        try {
            services = await Tuner_1.default.getServices({
                type: type,
                channel: channel
            });
        }
        catch (e) {
            res.write(`-> no signal. [${e}] \n\n`);
            continue;
        }
        services = services.filter(service => service.type === 1);
        res.write(`-> ${services.length} services found.\n`);
        if (services.length === 0) {
            res.write(`\n`);
            continue;
        }
        let name = services[0].name;
        for (const service of services) {
            for (let i = 1; i < name.length && i < service.name.length; i++) {
                if (name[i] !== service.name[i]) {
                    name = name.slice(0, i);
                    break;
                }
            }
        }
        name = name.trim();
        if (name.length === 0) {
            name = services[0].name || `${type}${channel}`;
        }
        const channelItem = {
            name: name,
            type: type,
            channel: channel
        };
        result.push(channelItem);
        ++count;
        res.write(`-> ${JSON.stringify(channelItem)}\n\n`);
    }
    result.sort((a, b) => {
        if (a.type === b.type) {
            return a.channel.localeCompare(b.channel, undefined, compareOptions);
        }
        else {
            return channelOrder[a.type] - channelOrder[b.type];
        }
    });
    config.saveChannels(result);
    res.write(`-> total ${count} channels found and ${result.length} channels stored.\n\n`);
    isScanning = false;
    res.write(`channel scan has completed and saved successfully.\n`);
    res.write(`**RESTART REQUIRED** to apply changes.\n`);
    res.end();
};
exports.put.apiDoc = {
    tags: ["config"],
    operationId: "channelScan",
    produces: [
        "text/plain",
        "application/json"
    ],
    parameters: [
        {
            in: "query",
            name: "type",
            type: "string",
            enum: ["GR"],
            default: "GR"
        },
        {
            in: "query",
            name: "min",
            type: "integer",
            default: 13
        },
        {
            in: "query",
            name: "max",
            type: "integer",
            default: 52
        }
    ],
    responses: {
        200: {
            description: "OK"
        },
        409: {
            description: "Already Scanning",
            schema: {
                $ref: "#/definitions/Error"
            }
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};
//# sourceMappingURL=scan.js.map